# Changelog

## [2.4.4a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.4.4a1) (2024-11-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.4.3...2.4.4a1)

**Merged pull requests:**

- nl-nl translation [\#292](https://github.com/OpenVoiceOS/OVOS-workshop/pull/292) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
